"""The root of the NailGun namespace.

NailGun's modules are organized in to layers, from bottom to top, like so:

1. :mod:`nailgun.client`
2. ``nailgun.orm``
3. ``nailgun.entities``

Some of these modules are in the process of being ported from Robottelo.

"""
